@@ -1,3 +1,5 @@
+# Copyright (c) OpenMMLab. All rights reserved.
+import copy
 import math
 import numbers
 import os.path as osp
@@ -55,7 +57,7 @@ class Resize:
             specified by ``mmcv.use_backend()`` will be used.
             Default: None.
         output_keys (list[str] | None): The resized images. Default: None
-            Note that if it is not `None`, its length shuld be equal to keys.
+            Note that if it is not `None`, its length should be equal to keys.
     """
 
     def __init__(self,
@@ -1030,3 +1032,167 @@ class MirrorSequence:
         repr_str = self.__class__.__name__
         repr_str += (f'(keys={self.keys})')
         return repr_str
+
+
+@PIPELINES.register_module()
+class CopyValues:
+    """Copy the value of a source key to a destination key.
+
+
+    It does the following: results[dst_key] = results[src_key] for
+    (src_key, dst_key) in zip(src_keys, dst_keys).
+
+    Added keys are the keys in the attribute "dst_keys".
+
+    Args:
+        src_keys (list[str]): The source keys.
+        dst_keys (list[str]): The destination keys.
+    """
+
+    def __init__(self, src_keys, dst_keys):
+
+        if not isinstance(src_keys, list) or not isinstance(dst_keys, list):
+            raise AssertionError('"src_keys" and "dst_keys" must be lists.')
+
+        if len(src_keys) != len(dst_keys):
+            raise ValueError('"src_keys" and "dst_keys" should have the same'
+                             'number of elements.')
+
+        self.src_keys = src_keys
+        self.dst_keys = dst_keys
+
+    def __call__(self, results):
+        """Call function.
+
+        Args:
+            results (dict): A dict containing the necessary information and
+                data for augmentation.
+
+        Returns:
+            dict: A dict with a key added/modified.
+        """
+        for (src_key, dst_key) in zip(self.src_keys, self.dst_keys):
+            results[dst_key] = copy.deepcopy(results[src_key])
+
+        return results
+
+    def __repr__(self):
+        repr_str = self.__class__.__name__
+        repr_str += (f'(src_keys={self.src_keys})')
+        repr_str += (f'(dst_keys={self.dst_keys})')
+        return repr_str
+
+
+@PIPELINES.register_module()
+class Quantize:
+    """Quantize and clip the image to [0, 1].
+
+    It is assumed that the the input has range [0, 1].
+
+    Modified keys are the attributes specified in "keys".
+
+    Args:
+        keys (list[str]): The keys whose values are clipped.
+    """
+
+    def __init__(self, keys):
+        self.keys = keys
+
+    def _quantize_clip(self, input_):
+        is_single_image = False
+        if isinstance(input_, np.ndarray):
+            is_single_image = True
+            input_ = [input_]
+
+        # quantize and clip
+        input_ = [np.clip((v * 255.0).round(), 0, 255) / 255. for v in input_]
+
+        if is_single_image:
+            input_ = input_[0]
+
+        return input_
+
+    def __call__(self, results):
+        """Call function.
+
+        Args:
+            results (dict): A dict containing the necessary information and
+                data for augmentation.
+
+        Returns:
+            dict: A dict with the values of the specified keys are rounded
+                and clipped.
+        """
+
+        for key in self.keys:
+            results[key] = self._quantize_clip(results[key])
+
+        return results
+
+    def __repr__(self):
+        return self.__class__.__name__
+
+
+@PIPELINES.register_module()
+class UnsharpMasking:
+    """Apply unsharp masking to an image or a sequence of images.
+
+    Args:
+        kernel_size (int): The kernel_size of the Gaussian kernel.
+        sigma (float): The standard deviation of the Gaussian.
+        weight (float): The weight of the "details" in the final output.
+        threshold (float): Pixel differences larger than this value are
+            regarded as "details".
+        keys (list[str]): The keys whose values are processed.
+
+    Added keys are "xxx_unsharp", where "xxx" are the attributes specified
+    in "keys".
+
+    """
+
+    def __init__(self, kernel_size, sigma, weight, threshold, keys):
+        if kernel_size % 2 == 0:
+            raise ValueError('kernel_size must be an odd number, but '
+                             f'got {kernel_size}.')
+
+        self.kernel_size = kernel_size
+        self.sigma = sigma
+        self.weight = weight
+        self.threshold = threshold
+        self.keys = keys
+
+        kernel = cv2.getGaussianKernel(kernel_size, sigma)
+        self.kernel = np.matmul(kernel, kernel.transpose())
+
+    def _unsharp_masking(self, imgs):
+        is_single_image = False
+        if isinstance(imgs, np.ndarray):
+            is_single_image = True
+            imgs = [imgs]
+
+        outputs = []
+        for img in imgs:
+            residue = img - cv2.filter2D(img, -1, self.kernel)
+            mask = np.float32(np.abs(residue) * 255 > self.threshold)
+            soft_mask = cv2.filter2D(mask, -1, self.kernel)
+            sharpened = np.clip(img + self.weight * residue, 0, 1)
+
+            outputs.append(soft_mask * sharpened + (1 - soft_mask) * img)
+
+        if is_single_image:
+            outputs = outputs[0]
+
+        return outputs
+
+    def __call__(self, results):
+        for key in self.keys:
+            results[f'{key}_unsharp'] = self._unsharp_masking(results[key])
+
+        return results
+
+    def __repr__(self):
+        repr_str = self.__class__.__name__
+        repr_str += (f'(keys={self.keys}, kernel_size={self.kernel_size}, '
+                     f'sigma={self.sigma}, weight={self.weight}, '
+                     f'threshold={self.threshold})')
+        return repr_str
