@@ -1,9 +1,12 @@
+# Copyright (c) OpenMMLab. All rights reserved.
 from .basicvsr_net import BasicVSRNet
+from .basicvsr_pp import BasicVSRPlusPlus
 from .dic_net import DICNet
 from .edsr import EDSR
 from .edvr_net import EDVRNet
 from .glean_styleganv2 import GLEANStyleGANv2
 from .iconvsr import IconVSR
+from .liif_net import LIIFEDSR, LIIFRDN
 from .rdn import RDN
 from .rrdb_net import RRDBNet
 from .sr_resnet import MSRResNet
@@ -14,5 +17,6 @@ from .ttsr_net import TTSRNet
 
 __all__ = [
     'MSRResNet', 'RRDBNet', 'EDSR', 'EDVRNet', 'TOFlow', 'SRCNN', 'DICNet',
-    'BasicVSRNet', 'IconVSR', 'RDN', 'TTSRNet', 'GLEANStyleGANv2', 'TDANNet'
+    'BasicVSRNet', 'IconVSR', 'RDN', 'TTSRNet', 'GLEANStyleGANv2', 'TDANNet',
+    'LIIFEDSR', 'LIIFRDN', 'BasicVSRPlusPlus'
 ]
