@@ -1,3 +1,4 @@
+# Copyright (c) OpenMMLab. All rights reserved.
 from .basic_restorer import BasicRestorer
 from .basicvsr import BasicVSR
 from .dic import DIC
@@ -5,11 +6,12 @@ from .edvr import EDVR
 from .esrgan import ESRGAN
 from .glean import GLEAN
 from .liif import LIIF
+from .real_esrgan import RealESRGAN
 from .srgan import SRGAN
 from .tdan import TDAN
 from .ttsr import TTSR
 
 __all__ = [
     'BasicRestorer', 'SRGAN', 'ESRGAN', 'EDVR', 'LIIF', 'BasicVSR', 'TTSR',
-    'GLEAN', 'TDAN', 'DIC'
+    'GLEAN', 'TDAN', 'DIC', 'RealESRGAN'
 ]
